@@ -111,7 +111,7 @@ def main():
         n_events = 1
 
     for event_index in range(n_events):
-        os.chdir(init_directory)
+        #os.chdir(init_directory)
         if is_event:
             fmin_template = float(
                 config.integrate_likelihood_cmds_dict["fmin-template"]
@@ -194,11 +194,12 @@ def main():
                 )
             event_info["output_event_ID"] = f"inj_{inj_index}"
             output_event_directory = event_info["output_event_ID"]
-            output_dir = os.path.join(
-                init_directory,
-                config.output_parent_directory, output_event_directory,
-                "",  # NOTE: trailing '/' might not be needed
-            )
+            output_dir = os.path.abspath(
+                    os.path.join(
+                        config.output_parent_directory, 
+                        output_event_directory,
+                        ),
+                    )
             event_all_iterations_fname = os.path.join(
                 output_dir, "event_all_iterations.dag",
             )
@@ -272,11 +273,7 @@ def main():
                         # TaylorT2 is the fastest in general.
                         event_info["approximant"] = "TaylorT2"
 
-            output_dir = os.path.join(
-                init_directory,
-                config.output_parent_directory,
-                ""  # TODO: confirm trailing '/' is needed
-            )
+            output_dir = os.path.abspath(config.output_parent_directory)
             if not os.path.isdir(output_dir):
                 os.makedirs(output_dir, exist_ok=True)
 
@@ -296,7 +293,7 @@ def main():
                 else:
                     # all approximants checked with BNS
                     event_info["approximant"] = "TaylorF2"
-        os.chdir(output_dir)
+        event_info["output_dir"] = output_dir
         if is_event:
             coinc_xml_filename = os.path.join(output_dir, "coinc.xml")
             # The PSD file name is set here, but it's written later because
@@ -342,10 +339,11 @@ def main():
                 data_type = config.event.frame_data_types[ifo]
                 # TODO: We should import gwdatafind and call the underlying
                 #       functions directly.
+                raw_cache_file_path = os.path.join(output_dir,f"{ifo[0]}_raw.cache")
                 dcmd = (
                     "python -m gwdatafind -u file "
                     f"-o {ifo[0]} -t {data_type} -s {data_start_time} "
-                    f"-e {data_end_time} > {ifo[0]}_raw.cache"
+                    f"-e {data_end_time} > {raw_cache_file_path}"
                 )
                 logging.info(dcmd)
                 exit_status = os.system(dcmd)
@@ -355,21 +353,22 @@ def main():
 
             # path2cache always assumes data is in output_dir, so that path
             # needs to be removed before passing output to data.cache
-            text_for_sed_removal = "localhost{}file:\\/".format(
-                output_dir.replace('/', '\\/')
+            text_for_sed_removal = "localhost{}\/file:\\/".format(
+                init_directory.replace('/', '\\/')
             )
             if shutil.which('lal_path2cache') is not None:
                 path2cache = 'lal_path2cache'
             else:
                 path2cache = 'lalapps_path2cache'
+            data_cache_file_path = os.path.join(output_dir,'data.cache')
             os.system(
-                "cat *_raw.cache "
+                f"cat {output_dir}/*_raw.cache "
                 f"| {path2cache} "
-                f"| sed 's/{text_for_sed_removal}//g' > data.cache"
+                f"| sed 's/{text_for_sed_removal}//g' > {data_cache_file_path}"
             )
 
             # Check if the data.cache file is empty
-            if os.stat("data.cache").st_size == 0:
+            if os.stat(data_cache_file_path).st_size == 0:
                 if lvalert and email_address_for_job_complete_notice != "":
                     email_cmd = (
                         f"Failed Lvalert, no data at trigger time "
@@ -385,7 +384,7 @@ def main():
                     "how can that happen?"
                 )
             # Put together cache file
-            event_info["cache_file"] = os.path.join(output_dir, "data.cache")
+            event_info["cache_file"] = data_cache_file_path
             event_info["psd_file"] = psd_file_str[:-1] + "]"
             event_info["channel_name"] = channel_str[:-1] + "]"
             event_info["coinc_xml_file"] = coinc_xml_filename
@@ -407,7 +406,7 @@ def main():
             )
             exe = config.exe_grid_refine
 
-            intrinsic_grid_name_base = "intrinsic_grid"
+            intrinsic_grid_name_base = os.path.join(output_dir,"intrinsic_grid")
             initial_grid_xml = intrinsic_grid_name_base+"_iteration_0.xml.gz"
             initial_grid_hdf = intrinsic_grid_name_base+"_all_iterations.hdf"
             # now fill in the rest
@@ -689,7 +688,7 @@ def main():
                 f"initial_grid_hdf={initial_grid_hdf}]"
             )
 
-        intrinsic_grid_name_base = "intrinsic_grid"
+        intrinsic_grid_name_base = os.path.join(output_dir,"intrinsic_grid")
         event_info["initial_grid_xml"] = (
             f"{intrinsic_grid_name_base}_iteration_0.xml.gz"
         )
